@@ -1,21 +1,24 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
-
 from .openapi import TuyaOpenAPI, TuyaTokenInfo
 from .openmq import TuyaOpenMQ
 from .asset import TuyaAssetManager
 from .device import TuyaDeviceManager, TuyaDevice, TuyaDeviceListener
 from .project_type import ProjectType
 from .home import TuyaHomeManager
+from .logging import tuya_logger
+from .version import VERSION
 
 __all__ = [
-    'TuyaOpenAPI',
-    'TuyaTokenInfo',
-    'TuyaOpenMQ',
-    'TuyaAssetManager',
-    'TuyaDeviceManager',
-    'TuyaDevice',
-    'TuyaDeviceListener',
-    'ProjectType',
-    'TuyaHomeManager',
+    "TuyaOpenAPI",
+    "TuyaTokenInfo",
+    "TuyaOpenMQ",
+    "TuyaAssetManager",
+    "TuyaDeviceManager",
+    "TuyaDevice",
+    "TuyaDeviceListener",
+    "ProjectType",
+    "TuyaHomeManager",
+    "tuya_logger"
 ]
+__version__ = VERSION
